@@ -1,9 +1,9 @@
 import os
 
-__version__ = "0.3.5"
+__version__ = "1.0.1"
 
 # This is the public client wallet.publisher.dnastack.com used if the user does not set their own
-default_auth = {
+DEFAULT_AUTH_PARAMS = {
     "url": "https://wallet.publisher.dnastack.com/",
     "client": {
         "redirect_url": "https://wallet.publisher.dnastack.com/",
@@ -11,19 +11,33 @@ default_auth = {
         "secret": "WpEmHtAiB73pCrhbEyci42sBFcfmWBdj",
     },
 }
+DEFAULT_AUTH_SCOPES = (
+    "openid "
+    "offline_access "
+    "drs-object:write "
+    "drs-object:access "
+    "dataconnect:info "
+    "dataconnect:data "
+    "dataconnect:query "
+    "wes"
+)
 
-cli_directory = f"{os.path.expanduser('~')}/.dnastack"
-config_file_path = f"{cli_directory}/config.yaml"
-downloads_directory = f"{os.getcwd()}"
+CLI_DIRECTORY = f"{os.path.expanduser('~')}/.dnastack"
 
 # NOTE: This is not necessarily all the possible config keys, but all of the settable ones
 # also include types for the config keys
 ACCEPTED_CONFIG_KEYS = {
     "data_connect": {
         "url": str,
-        "wallet": {
+        "auth": {
             "url": str,
-            "client": {"id": str, "secret": str, "redirect_url": str},
+            "authorization_url": str,
+            "device_code_url": str,
+            "token_url": str,
+            "refresh_token": str,
+            "email": str,
+            "personal_access_token": str,
+            "client": {"id": str, "secret": str, "redirect_url": str, "scope": str},
         },
     },
     "user": {
@@ -35,20 +49,38 @@ ACCEPTED_CONFIG_KEYS = {
     },
     "collections": {
         "url": str,
-        "wallet": {
+        "auth": {
             "url": str,
-            "client": {"id": str, "secret": str, "redirect_url": str},
+            "authorization_url": str,
+            "device_code_url": str,
+            "token_url": str,
+            "refresh_token": str,
+            "email": str,
+            "personal_access_token": str,
+            "client": {"id": str, "secret": str, "redirect_url": str, "scope": str},
         },
     },
     "wes": {
         "url": str,
-        "wallet": {
+        "auth": {
             "url": str,
-            "client": {"id": str, "secret": str, "redirect_url": str},
+            "authorization_url": str,
+            "device_code_url": str,
+            "token_url": str,
+            "refresh_token": str,
+            "email": str,
+            "personal_access_token": str,
+            "client": {"id": str, "secret": str, "redirect_url": str, "scope": str},
         },
     },
+    "tokens": list,
+    "service_registry": {"url": str},
 }
 
+
+# Config keys to not display/persist in config.yaml
+HIDDEN_CONFIG_KEYS = ["client", "debug"]
+
 # The configs in oauth.[SERVER].* that are settable by the user
 ACCEPTED_OAUTH_KEYS = {"access_token": str, "refresh_token": str, "scope": list}
 
@@ -58,7 +90,7 @@ DEPRECATED_CONFIG_KEYS = {
     "wes-url": "wes.url",
     "data-connect-url": "data_connect.url",
     "collections-url": "collections.url",
-    "oauth_token.refresh_token": "oauth.refresh_token",
+    "oauth_token.refresh_token": None,
     "personal_access_token": "user.personal_access_token",
     "email": "user.email",
     "wallet-url": None,
@@ -68,15 +100,6 @@ DEPRECATED_CONFIG_KEYS = {
     "oauth_token": None,
 }
 
-SUPPORTED_SERVICES = ["wes", "collections", "data-connect"]
+SUPPORTED_SERVICES = ["wes", "collections", "dataconnect"]
 
-auth_scopes = (
-    "openid "
-    "offline_access "
-    "drs-object:write "
-    "drs-object:access "
-    "dataconnect:info "
-    "dataconnect:data "
-    "dataconnect:query "
-    "wes"
-)
+DEFAULT_SERVICE_REGISTRY = "https://ga4gh-service-registry.publisher.dnastack.com/"
